==> plot_data-0.20.0.tar.gz: plot_data-0.20.0/README.md <==
# Plot Data: Plot and draw your Python data on your web browser
[![npm (scoped)](https://img.shields.io/npm/v/plot-data.svg)](https://www.npmjs.com/package/plot-data)
[![npm bundle size (minified)](https://img.shields.io/bundlephobia/min/plot-data.svg)](https://www.npmjs.com/package/plot-data)
![npm](https://img.shields.io/npm/dt/plot-data)
![GitHub last commit](https://img.shields.io/github/last-commit/Dessia-tech/plot_data)

## Introduction
Plot Data is a Python library that allows to plot and draw interactive figures on your web browser.
With Plot Data you will be able to draw:
- Scatters:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/1fb8af76-f6eb-46e6-9fe6-d0535a9d7034)

- Graphs:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/eef16371-0801-4165-919e-57e138d054e6)

- Histograms:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/f6da4f39-6d20-4a0f-8bcc-cff63fda0e8a)

- Parallel plots:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/c6c2b367-871c-400d-bb3e-a1042a454862)

- Draws:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/8c7f6767-1c81-45c6-8373-75e3b3d31923)

- And put this all together in a Multiplot:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/587a9e4e-4b9d-46de-be18-42f9bf918416)

## Install

```
npm i plot-data
```

## Usage

```
import * as plotdata from 'plot-data';
```

## Develop

```
npm i
npm run dev
```

## Documentation

Python: https://documentation.dessia.tech/plot_data/python/ <br>
Typescript: https://documentation.dessia.tech/plot_data/typescript/

## Changelog

Check the changelog [here](CHANGELOG.md)

==> plot_data-0.26.1.tar.gz: plot_data-0.26.1/README.md <==
# Plot Data: Plot and draw your Python data on your web browser
[![npm (scoped)](https://img.shields.io/npm/v/plot-data.svg)](https://www.npmjs.com/package/plot-data)
[![npm bundle size (minified)](https://img.shields.io/bundlephobia/min/plot-data.svg)](https://www.npmjs.com/package/plot-data)
![npm](https://img.shields.io/npm/dt/plot-data)
![GitHub last commit](https://img.shields.io/github/last-commit/Dessia-tech/plot_data)

## Introduction
Plot Data is a Python library that allows to plot and draw interactive figures on your web browser.
With Plot Data you will be able to draw:
- Scatters:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/1fb8af76-f6eb-46e6-9fe6-d0535a9d7034)

- Graphs:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/eef16371-0801-4165-919e-57e138d054e6)

- Histograms:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/f6da4f39-6d20-4a0f-8bcc-cff63fda0e8a)

- Parallel plots:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/c6c2b367-871c-400d-bb3e-a1042a454862)

- Draws:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/8c7f6767-1c81-45c6-8373-75e3b3d31923)

- And put this all together in a Multiplot:
  ![image](https://github.com/Dessia-tech/plot_data/assets/106539650/587a9e4e-4b9d-46de-be18-42f9bf918416)

## Install

```
npm i plot-data
```

## Usage

```
import * as plotdata from 'plot-data';
```

## Develop

```
npm i
npm run dev
```

## Documentation

https://documentation.dessia.io/tutorials/tutorial-4/ <br>

## Changelog

Check the changelog [here](CHANGELOG.md)
